
Credits
=======

Development Lead
----------------

* Mark Bell <mcbell@illinois.edu>

Contributors
------------

* Nathan M Dunfield <nmd@illinois.edu> - Code for constructing taut strunctures on bundles.
